'use strict';
/**
 * Returns a copy of a JavaScript object with the keys arranged in a specified order.
 * @param {object} data The unarranged source object.
 * @param {string[]|string|false} [keys] The keys that we wish to arrange at the top. Can be a an array of keys. A string of keys seperated by a space character. Or false, to just sort the keys of the object.
 * @param {boolean} [sort=false] If true, the remaining keys are sorted.
 * @returns {object} The arranged object.
 */

function arrangekeys(data) {
  var keys = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var sort = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  // Prepare
  var result = {}; // Expand

  if (!keys) {
    sort = true;
  } else {
    if (typeof keys === 'string') {
      keys = keys.split(/\s+/);
    } // Add the specified keys in the specified order


    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = keys[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        var key = _step.value;

        if (typeof data[key] !== 'undefined') {
          result[key] = data[key];
        }
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator.return != null) {
          _iterator.return();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }
  } // Add the leftovers


  var dataKeys = sort ? Object.keys(data).sort() : Object.keys(data);
  var _iteratorNormalCompletion2 = true;
  var _didIteratorError2 = false;
  var _iteratorError2 = undefined;

  try {
    for (var _iterator2 = dataKeys[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
      var _key = _step2.value;
      result[_key] = data[_key]; // no need for !(key in keys) as we assume the JS engine handles that for us
    } // Return the result

  } catch (err) {
    _didIteratorError2 = true;
    _iteratorError2 = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion2 && _iterator2.return != null) {
        _iterator2.return();
      }
    } finally {
      if (_didIteratorError2) {
        throw _iteratorError2;
      }
    }
  }

  return result;
} // Export


module.exports = arrangekeys;